/*  ethload.h : Ethernet Loader for embedded devices.
    Copyright (C) 1999  Ludovic LANGE <ludovic.lange@free.fr>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _ETHLOAD_H
#define _ETHLOAD_H

/*Define constants*/
/******************/

#define	EDBG_PORT	980		/* Debug port for starting communication */

#define EDBG_SIGNATURE	('E'+('D'<<8)+('B'<<16)+('G'<<24))	/* "EDBG" reversed, i.e. "GBDE" */
#define EDBG_FIELD1	0xFF		/* constant data for field 1 */
#define EDBG_FIELD2	0x00		/* constant data for field 2 */
#define EDBG_FIELD3	0x00		/* constant data for field 3 */

/* Various commands for EDBG packets */
#define EDBG_CMD_BOOTME	0		/*From device to ethload : ask a rom*/
#define EDBG_CMD_CMD1	1
#define EDBG_CMD_JUMP   2		/*From ethload to device : jump to freshly downloaded image*/
#define EDBG_CMD_CMD3	3
#define EDBG_CMD_CMD4	4
#define EDBG_CMD_CMD5	5
#define EDBG_CMD_CMD6	6		/* ??? */
#define EDBG_CMD_CMD7	7		/* ??? */

/*  architecture value anded with 0xF0.  Use in switch statement to print to screen */
#define EDBG_ARCH_SHx	0x10
#define EDBG_ARCH_MIPS	0x20
#define EDBG_ARCH_ARM	0x30


/* Structures */
/**************/

typedef struct
{
    long		signature;	// This should be EDBG_SIGNATURE
    unsigned char	field1;		// Unknown field1 : 0xFF
    unsigned char	field2;		// Unknown field2 : 0x01
    unsigned char	field3;		// Unknown field3 : 0x00
    unsigned char	command;
    unsigned char	data[1];
} EDBG_PACKET;


typedef struct
{
    unsigned char	majorVersion;	//Version of bootloader, device side ?
    unsigned char	minorVersion; 	//Version of bootloader, device side ?
    unsigned short	MACAddr[3];		//MAC adress of device
    long		ipAddr;
    unsigned char	genericName[17];	//Name of product line
    unsigned char	deviceName[17];		//Name of device (different for each device of same product line)
    unsigned char	architecture;
} EDBG_DATA_BOOTME;

#endif // _ETHLOAD_H
